% Required for the Matlab code example for Algorithm 1 presented in "Sparse 
% Fast DCT for Vectors with One-Block Support" by Sina Bittens and Gerlind
% Plonka.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [ supp_struct, mu, m ] = find_supp_0( y, epsilon)
%FIND_SUPP_0 Finds the support structure of y=y^(b) if nothing about its 
% support is known.
% supp_struct==1 if y has a one-block support, supp_struct==2 if y has a
% two-block support and supp_struct==3 if it has a two-block support with 
% possibly different block lenghts (only possible for j=J-1).

% Since y^(b) is symmetric, it suffices to examine the first half of it.
N=length(y);
y_0=y(1:N/2);
T=find(y_0>epsilon)-1
if T(1)==0 && T(end)~=N/2-1
    % y has a one-block support of length m<N.
    supp_struct=1;
    mu=N-1-T(end);
    m=2*(T(end)+1);
elseif T(end)==N/2-1 && T(1)~=0
    % y has a one-block support of length m<N.
    supp_struct=1;
    mu=T(1);
    m=2*(T(end)-T(1)+1);
elseif T(end)==N/2-1 && T(1)==0
    % y has a one-block support of length m=N.
    supp_struct=1;
    mu=0;
    m=N;
else
    % y has a two-block support of block length m<N/2.
    supp_struct=2;
    mu=T(1);
    m=T(end)-T(1)+1;
end

